%bcond_with enc_x264
%bcond_with dec_avcodec
%bcond_with csc_swscale

# These are nececessary as the _with_foo is *not* defined if the
# --with flag isn't specifed, and we need to have the --without
# specified option in that case.
%if !%{with enc_x264}
%define _with_enc_x264 --without-enc_x264
%endif

%if !%{with dec_avcodec}
%define _with_dec_avcodec --without-dec_avcodec
%endif

%if !%{with csc_swscale}
%define _with_csc_swscale --without-csc_swscale
%endif

# Remove private provides from .so files in the python_sitearch directory
%global __provides_exclude_from ^%{python_sitearch}/.*\\.so$

Name:           xpra
Version:        0.14.22
Release:        4%{?dist}
Summary:        Remote display server for applications and desktops

License:        GPLv2+ and BSD and LGPLv3+ and MIT
URL:            https://www.xpra.org/
Source0:        https://xpra.org/src/%{name}-%{version}.tar.xz

# patch setup.py to disable building bundled libraries
Patch1:         %{name}-unbundle-rencode.patch
# Patch to remove reference to the xorg void driver from xorg.conf
# This patch can be removed for 0.15 as merged upstream
# See:
# http://xpra.org/trac/ticket/843
# https://bugzilla.redhat.com/show_bug.cgi?id=1215527
Patch2:         xpra-0.14-stop-using-void-driver.patch
# This patch fixes up the paragraphs to end with a period so the
# validation doesn't bail. It also expands the text to be more
# helpful.
Patch3:         xpra-0.14.22-appdata.patch

BuildRequires:  python2-devel pygobject2-devel pygtk2-devel
BuildRequires:  libXtst-devel
BuildRequires:  libxkbfile-devel
BuildRequires:  Cython
BuildRequires:  desktop-file-utils
BuildRequires:  libvpx-devel
BuildRequires:  libwebp-devel
BuildRequires:  libappstream-glib
%if %{with enc_x264}
BuildRequires:  x264-devel
%endif
%if %{with dec_avcodec} || %{with csc_swscale}
BuildRequires:  ffmpeg-devel
%endif

Requires:       python-imaging
Requires:       dbus-python
Requires:       xorg-x11-server-utils xorg-x11-server-Xvfb
Requires:       xorg-x11-drv-dummy
Requires:       PyOpenGL pygtkglext
Requires:       python-numeric numpy
Requires:       gstreamer gstreamer-python
Requires:       gstreamer-plugins-base gstreamer-plugins-good
Requires:       pulseaudio pulseaudio-utils
Requires:       python-rencode
Requires:       js-web-socket-js
Requires:       js-jquery

Provides:       bundled(js-jquery-ui) = 1.10.4
%if 0%{?fedora} >= 21
Requires:       js-zlib
%else
Provides:       bundled(js-zlib)
%endif


%description
Xpra is "screen for X": it allows you to run X programs, usually on a remote
host, direct their display to your local machine, and then to disconnect from
these programs and reconnect from the same or another machine, without losing
any state. It gives you remote access to individual applications.

Xpra is "rootless" or "seamless": programs you run under it show up on your
desktop as regular programs, managed by your regular window manager.
Sessions can be accessed over SSH, or password protected over plain TCP sockets.
Xpra is usable over reasonably slow links and does its best to adapt to changing
network bandwidth constraints.


%prep
%setup -q
%patch1 -p1
%patch2 -p1
%patch3 -p1

#use the system python-rencode
rm -f xpra/net/rencode/*
echo "from rencode import *" > xpra/net/rencode/__init__.py
echo "from rencode._rencode import __version__" >> xpra/net/rencode/__init__.py

%build
CFLAGS="%{optflags}" %{__python} setup.py build \
    --with-vpx \
    --with-webp \
    %{?_with_enc_x264} \
    %{?_with_dec_avcodec} \
    %{?_with_csc_swscale} \
    --with-Xdummy \
    --with-Xdummy_wrapper


%install
%{__python} setup.py install --skip-build --root %{buildroot}

#move icon to proper directory
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/48x48/apps
mv %{buildroot}%{_datadir}/icons/xpra.png \
    %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/

#remove doc stuff from /usr/share
rm -f \
    %{buildroot}%{_datadir}/xpra/README \
    %{buildroot}%{_datadir}/xpra/COPYING

#drop shebangs from python_sitearch
find %{buildroot}%{python_sitearch}/xpra -name '*.py' \
    -exec sed -i '1{\@^#!/usr/bin/env python@d}' {} \;

#fix permissions on shared objects
find %{buildroot}%{python_sitearch}/xpra -name '*.so' \
    -exec chmod 0755 {} \;

# delete any bundled SWFs - binary content forbidden by packaging
# guidelines
find %{buildroot}%{_datadir}/xpra -name '*.swf' -exec rm {} \;

# Use system js-query rather than the bundled one
ln -sf ../../../javascript/jquery/2/jquery.min.js \
    %{buildroot}%{_datadir}/xpra/www/include/jquery.min.js

# Use system web-socket-js rather than the bundled one
rm -rf %{buildroot}%{_datadir}/xpra/www/include/web-socket-js
ln -sf ../../../javascript/web-socket-js \
    %{buildroot}%{_datadir}/xpra/www/include/web-socket-js

# Use system js-zlib instead of bundled one on Fedora >= 21
%if 0%{?fedora} >= 21
for file in deflate.min.js inflate.min.js ; do
    ln -sf ../../../javascript/zlib/$file \
       %{buildroot}%{_datadir}/xpra/www/include/$file
done
%endif

# Ensure all .js files are not executeable
find %{buildroot}%{_datadir}/xpra/www/include -name '*.js' \
    -exec chmod 0644 {} \;

appstream-util validate-relax --nonet %{buildroot}/%{_datadir}/appdata/xpra.appdata.xml


%check
desktop-file-validate %{buildroot}%{_datadir}/applications/xpra.desktop
desktop-file-validate %{buildroot}%{_datadir}/applications/xpra_launcher.desktop


%post
/usr/bin/update-desktop-database &> /dev/null || :
/bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :


%postun
/usr/bin/update-desktop-database &> /dev/null || :

if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi


%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :


%files
%dir %{_sysconfdir}/xpra
%config(noreplace) %{_sysconfdir}/xpra/xorg.conf
%config(noreplace) %{_sysconfdir}/xpra/xpra.conf
%{_bindir}/xpra
%{_bindir}/xpra_Xdummy
%{_bindir}/xpra_launcher
%{python_sitearch}/xpra
%{python_sitearch}/*.egg-info
%{_datadir}/applications/xpra*.desktop
%{_datadir}/icons/hicolor/48x48/apps/xpra.png
%{_mandir}/man1/xpra.1.*
%{_mandir}/man1/xpra_launcher.1.*
%{_datadir}/xpra
%{_datadir}/appdata/xpra.appdata.xml
%doc README COPYING NEWS


%changelog
* Tue Apr 28 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.14.22-4
- Patch appdata file to have more information and proper paragraph
  ending period so validation works

* Mon Apr 27 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.14.22-3
- Remove Requires for xorg-x11-drv-void

* Mon Apr 27 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.14.22-2
- Validate and own /usr/share/appdata/xpra.appdata.xml
- Add BuildRequires libappstream-glib

* Mon Apr 27 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.14.22-1
- Update to 0.14.22

* Mon Apr 27 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.14.21-5
- Add patch to remove reference to the xorg void driver in xorg.conf (BZ #1215527)

* Mon Apr  6 2015 Tom Callaway <spot@fedoraproject.org> - 0.14.21-4
- rebuild for libvpx 1.4.0

* Tue Mar 24 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.14.21-3
- Update license tag from GPLv2+ to GPLv2+ and BSD and LGPLv3+ and MIT

* Mon Mar 23 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.14.21-2
- Add conditionals for building with ffmpeg and x264 support, disabled
  by default
- Remove Provides for bundled(js-web-socket-js)
- Use system js-zlib on Fedora >= 21
- On Fedora < 21 add Provides for bundled(js-zlib)

* Wed Mar 18 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.14.21-1
- Update to 0.14.21

* Wed Mar 18 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.14.19-6
- Unbundle js-query even on Fedora 20

* Wed Mar 18 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.14.19-5
- Unbundle web-socket-js

* Tue Mar  3 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.14.19-4
- Add --with-Xdummy and --with-Xdummy_wrapper build options since Xorg
  not installed at build time so autodetection fails

* Tue Mar  3 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.14.19-3
- Use js-jquery package only on F22 or later - not available on
  earlier distros

* Tue Mar  3 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.14.19-2
- Update Summary to be more descriptive of package
- Use packaged js-jquery
- Add provides for bundled(js-jquery-ui) and bundled(js-web-socket-js)
- Build with vpx and webp support enabled
- Remove any installed SWF files
- Remove executable flag for all .js files
- Remove Requires for python-webm

* Tue Mar  3 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.14.19-1
- Update to upstream 0.14.19
- Add BuildRequires for libxkbfile-devel
- No longer need to unbundle webp
- Rework and rename patch for unbundling of rencode

* Fri Oct 18 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.10.6-1
- new upstream release 0.10.6
  http://lists.devloop.org.uk/pipermail/shifter-users/2013-October/000726.html

* Tue Oct 08 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.10.4-2
- reenable webp support
- fix webm unbundling to support importing all modules in the webm package
- require latest python-webm so it matches what's bundled upstream

* Mon Oct 07 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.10.4-1
- rebase to 0.10.4
- don't ship webm stuff that doesn't work without ffmpeg anyway

* Thu Aug 01 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.9.8-1
- new upstream release 0.9.8
  http://lists.devloop.org.uk/pipermail/shifter-users/2013-July/000615.html
- use HTTPS for URL and Source0

* Wed Jul 03 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.9.6-1
- new upstream release 0.9.6
  http://lists.devloop.org.uk/pipermail/shifter-users/2013-June/000552.html

* Thu Jun 27 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.9.5-1
- new upstream release 0.9.5
  http://lists.devloop.org.uk/pipermail/shifter-users/2013-June/000549.html

* Thu May 30 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.9.4-1
- new upstream release 0.9.4
  http://lists.devloop.org.uk/pipermail/shifter-users/2013-May/000539.html

* Mon May 13 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.9.2-1
- new upstream release 0.9.2
  http://lists.devloop.org.uk/pipermail/shifter-users/2013-May/000525.html

* Fri May 10 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.9.1-1
- new upstream release 0.9.1
  http://lists.devloop.org.uk/pipermail/shifter-users/2013-May/000522.html

* Tue May 07 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.9.0-2
- fix rencode __version__ importing

* Thu May 02 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.9.0-1
- new upstream release 0.9.0
  http://lists.devloop.org.uk/pipermail/shifter-users/2013-April/000479.html
- delete the bundled code in prep instead of inside the patches
- don't bother including parti; it's going away upstream soon
- merge python-wimpiggy into main xpra package; it won't be seperated upstream soon

* Thu Apr 18 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.8.8-4
- unbundle rencode and webm
- fix equality operator in Requires
- drop unnecessary multiple copies of NEWS
- don't remove buildroot

* Thu Apr 11 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.8.8-3
- drop unmet dependency on gstreamer-plugins-ugly
- fix permissions on shared objects
- add scriptlets necessary for icon/desktop file

* Thu Mar 28 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.8.8-2
- disable codecs prohibited in Fedora

* Thu Mar 14 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.8.8-1
- initial package
